@@ -1,10 +1,14 @@
 from widgets.streamlit.resource.base import StResource # noqa
 from widgets.streamlit.resource.dataframe import StDataFrame # noqa
+from widgets.streamlit.resource.dataframe import StDownloadDataFrame # noqa
 from widgets.streamlit.resource.expander import StExpander # noqa
+from widgets.streamlit.resource.columns import StColumns # noqa
 from widgets.streamlit.resource.value import StCheckbox # noqa
 from widgets.streamlit.resource.value import StFloat # noqa
 from widgets.streamlit.resource.value import StInteger # noqa
 from widgets.streamlit.resource.value import StSelectString # noqa
+from widgets.streamlit.resource.value import StMultiSelect # noqa
 from widgets.streamlit.resource.value import StString # noqa
 from widgets.streamlit.resource.value import StSlider # noqa
+from widgets.streamlit.resource.markdown import StMarkdown # noqa
 from widgets.streamlit.widget.base import StreamlitWidget # noqa
